@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 # Created by Roberto Preste
-from apybiomart.apybiomart import find_marts, find_datasets, find_attributes, \
-    find_filters, query, aquery
+from apybiomart.apybiomart import (  # noqa
+    find_marts, find_datasets, find_attributes, find_filters, query, aquery
+)
 
 __author__ = """Roberto Preste"""
 __email__ = 'robertopreste@gmail.com'
-__version__ = '0.5.0'
+__version__ = '0.5.3'
